import { relations } from "drizzle-orm";
import {
	integer,
	pgTable,
	varchar,
	text,
	timestamp,
} from "drizzle-orm/pg-core";

export const users = pgTable("users", {
	id: integer().primaryKey().generatedAlwaysAsIdentity(),
	username: varchar({ length: 128 }).unique().notNull(),
	passwordHash: text(),
	displayName: text(),
});

export const sessions = pgTable("sessions", {
	id: text().primaryKey(),
	userId: integer()
		.notNull()
		.references(() => users.id),
	expiresAt: timestamp({ withTimezone: true }).notNull(),
});

export const sessionRelations = relations(sessions, ({ one }) => ({
	user: one(users, { 
		fields: [ sessions.userId ],
		references: [users.id],
	}),
}));
