import { eq } from "drizzle-orm";
import { db } from "./db";
import { users } from "./schema";

export interface User {
    id: number;
    username: string;
    displayName?: string;
}


export async function getUserFromUsername(username: string): Promise<User | null> {
    const user = await db.query.users.findFirst({
        columns: {
            id: true,
            username: true,
            displayName: true
        },
        where: eq(users.username, username)
    });

	if (!user) {
		return null;
	}

	return {
        ...user,
        displayName: user.displayName || undefined,
    };
}

export async function getUserPasswordHash(userId: number): Promise<string|null> {
    const user = (await db.query.users.findFirst({
        columns: {
            passwordHash: true,
        },
        where: eq(users.id, userId)
    }));

    if (user === undefined) {
        throw new Error("Invalid user ID");
    }

    return user.passwordHash;
}