import { fail, redirect, type Actions } from "@sveltejs/kit";

import type { PageServerLoad } from "./$types";
import {
	deleteSessionTokenCookie,
	invalidateSession,
} from "$lib/server/session";

export const load: PageServerLoad = (event) => {
	if (event.locals.session !== null && event.locals.user !== null) {
		return redirect(302, "/");
	}
	return {};
};

export const actions = {
	default: async (event) => {
		if (event.locals.session === null) {
			return fail(401, {
				message: "Not authenticated",
			});
		}

		await invalidateSession(event.locals.session.id);
		deleteSessionTokenCookie(event);
		return redirect(303, "/login");
	},
} satisfies Actions;
